=== modified file 'drizzled/message/statement_transform.cc'
--- drizzled/message/statement_transform.cc	2010-12-24 16:11:53 +0000
+++ drizzled/message/statement_transform.cc	2011-01-03 16:50:13 +0000
@@ -860,6 +860,13 @@
 
   destination.append("DROP TABLE ", 11);
 
+  /* Add the IF EXISTS clause if necessary */
+  if (statement.has_if_exists_clause() &&
+      statement.if_exists_clause() == true)
+  {
+    destination.append("IF EXISTS ", 10);
+  }
+
   destination.push_back(quoted_identifier);
   destination.append(table_metadata.schema_name());
   destination.push_back(quoted_identifier);

=== modified file 'drizzled/message/transaction.proto'
--- drizzled/message/transaction.proto	2010-12-21 20:47:29 +0000
+++ drizzled/message/transaction.proto	2011-01-03 16:50:13 +0000
@@ -507,6 +507,7 @@
 message DropTableStatement
 {
   required TableMetadata table_metadata = 1; /* Minimal metadata about the table to be dropped */
+  optional bool if_exists_clause = 2; /* Did the user specify an IF EXISTS clause? */
 }
 
 /*

=== modified file 'drizzled/plugin/schema_engine.cc'
--- drizzled/plugin/schema_engine.cc	2011-01-03 05:34:58 +0000
+++ drizzled/plugin/schema_engine.cc	2011-01-04 00:36:55 +0000
@@ -224,7 +224,7 @@
       my_error(ER_TABLE_DROP, MYF(0), (*it).getTableName().c_str());
       return false;
     }
-    transaction_services.dropTable(&session, (*it).getSchemaName(), (*it).getTableName());
+    transaction_services.dropTable(&session, (*it).getSchemaName(), (*it).getTableName(), true);
     deleted++;
   }
 

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2010-12-24 07:15:43 +0000
+++ drizzled/sql_table.cc	2011-01-03 16:50:13 +0000
@@ -218,7 +218,7 @@
         if (error == 0)
         {
           TransactionServices &transaction_services= TransactionServices::singleton();
-          transaction_services.dropTable(session, string(table->getSchemaName()), string(table->getTableName()));
+          transaction_services.dropTable(session, string(table->getSchemaName()), string(table->getTableName()), if_exists);
         }
 
         if ((error == ENOENT || error == HA_ERR_NO_SUCH_TABLE) && if_exists)

=== modified file 'drizzled/transaction_services.cc'
--- drizzled/transaction_services.cc	2010-12-23 18:45:30 +0000
+++ drizzled/transaction_services.cc	2011-01-03 16:50:13 +0000
@@ -2064,7 +2064,8 @@
 
 void TransactionServices::dropTable(Session *in_session,
                                     const string &schema_name,
-                                    const string &table_name)
+                                    const string &table_name,
+                                    bool if_exists)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
   if (! replication_services.isActive())
@@ -2081,6 +2082,8 @@
    */
   message::DropTableStatement *drop_table_statement= statement->mutable_drop_table_statement();
 
+  drop_table_statement->set_if_exists_clause(if_exists);
+
   message::TableMetadata *table_metadata= drop_table_statement->mutable_table_metadata();
 
   table_metadata->set_schema_name(schema_name);

=== modified file 'drizzled/transaction_services.h'
--- drizzled/transaction_services.h	2010-12-21 20:47:29 +0000
+++ drizzled/transaction_services.h	2011-01-03 16:50:13 +0000
@@ -317,10 +317,12 @@
    * @param[in] in_session Pointer to the Session which issued the statement
    * @param[in] schema_name The schema of the table being dropped
    * @param[in] table_name The table name of the table being dropped
+   * @param[in] if_exists Did the user specify an IF EXISTS clause?
    */
   void dropTable(Session *in_session,
                      const std::string &schema_name,
-                     const std::string &table_name);
+                     const std::string &table_name,
+                     bool if_exists);
   /**
    * Creates a TruncateTable Statement GPB message and adds it
    * to the Session's active Transaction GPB message for pushing

=== modified file 'plugin/transaction_log/tests/r/ddl_transaction_id.result'
--- plugin/transaction_log/tests/r/ddl_transaction_id.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/ddl_transaction_id.result	2011-01-03 16:50:13 +0000
@@ -41,6 +41,7 @@
       schema_name: "test"
       table_name: "t1"
     }
+    if_exists_clause: false
   }
 }
 
@@ -210,6 +211,7 @@
       schema_name: "test"
       table_name: "t1"
     }
+    if_exists_clause: false
   }
 }
 

=== modified file 'plugin/transaction_log/tests/r/information_schema.result'
--- plugin/transaction_log/tests/r/information_schema.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/information_schema.result	2011-01-03 16:50:13 +0000
@@ -34,6 +34,7 @@
       schema_name: "test"
       table_name: "t1"
     }
+    if_exists_clause: false
   }
 }
 
@@ -191,6 +192,7 @@
       schema_name: "test"
       table_name: "t1"
     }
+    if_exists_clause: false
   }
 }
 

=== modified file 'plugin/transaction_log/tests/r/transaction_log_drop.result'
--- plugin/transaction_log/tests/r/transaction_log_drop.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/transaction_log_drop.result	2011-01-03 16:50:13 +0000
@@ -29,6 +29,7 @@
       schema_name: "test"
       table_name: "t1"
     }
+    if_exists_clause: false
   }
 }
 
@@ -59,6 +60,7 @@
       schema_name: "test"
       table_name: "t3"
     }
+    if_exists_clause: false
   }
 }
 
@@ -77,6 +79,7 @@
       schema_name: "test"
       table_name: "t2"
     }
+    if_exists_clause: false
   }
 }
 
@@ -95,6 +98,7 @@
       schema_name: "test"
       table_name: "t1"
     }
+    if_exists_clause: false
   }
 }
 
@@ -131,6 +135,7 @@
       schema_name: "test"
       table_name: "t1"
     }
+    if_exists_clause: true
   }
 }
 

=== modified file 'plugin/transaction_log/tests/r/transaction_log_schema.result'
--- plugin/transaction_log/tests/r/transaction_log_schema.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/transaction_log_schema.result	2011-01-03 16:50:13 +0000
@@ -106,6 +106,7 @@
       schema_name: "my_test_schema"
       table_name:  TABLE_NAME
     }
+    if_exists_clause: true
   }
 }
 

